function [tout, xout] = my_euler(ODEsys, t_int, x0, tau)

% Funkcija za rjesavanje problema pocetnih uvjeta: 
% x'(t) = f(x, t), x(0) = x0
% primjenom Eulerove metode

% tout - izlaz --> vrijeme
% xout - izlaz --> vektor varijabli stanja
% ODEsys - ulaz --> sustav dif. jednadzbi f(x, t)
% tspan - ulaz --> vremenski interval
% x0 - ulaz --> vektor pocetnih uvjeta
% tau - ulaz --> vremenski korak

% Inicijalizacija
t0 = t_int(1); 
tf = t_int(2);

N = (tf-t0)/tau;
x = x0(:);

% Inicijalizacija izlaza
xout = zeros(N+1, size(x, 1)); 
tout = zeros(N+1, 1); 


% % Algoritam
% for i = 1:N+1 
%   tout(i) = t0 + (i-1)*tau;
%   t = tout(i);
%   f = feval(ODEsys, t, x); 
%   f = f(:);  
%   x = x + tau*f;	
%   xout(i, :) = x';
% end

%% ILI POMOCU WHILE PETLJE

% Algoritam
t = t0;
xout(1, :) = x';
tout(1) = t;
k = 1;
while (k < N+1) 
  if (t + tau - tf) > 0 
    tau = tf - t; 
    tout(k+1) = tf;
  else
    tout(k+1) = t0 +k*tau;
  end
  k = k+1;
  
  f = feval(ODEsys, t, x); f = f(:);  
  x = x + tau*f;	
  t = tout(k);
  xout(k, :) = x';
end

